
/* SideBar*/
.webix_sidebar{
	background: #ECEFF1;
}
.webix_sidebar .webix_tree_item {
	color: #454545;
	height: 35px;
	line-height: 35px;
}
.webix_sidebar .webix_scroll_cont > .webix_tree_leaves {
	padding: 0;
}
.webix_sidebar .webix_tree_leaves .webix_tree_leaves {
	margin-left: 0px;
}
.webix_sidebar_selected,
.webix_sidebar_expanded .webix_tree_item:hover{
	background-color: rgba(0,0,0,0.02);
}
.webix_sidebar .webix_tree_item.webix_selected,
.webix_sidebar .webix_tree_item.webix_selected span{
	background-color: #27ae60;
	padding-right:0;
}
.webix_sidebar .webix_tree_branch_1 .webix_tree_item{
	padding-left:40px;
}
.webix_sidebar .webix_tree_branch_1>.webix_tree_item{
	height: 40px;
	line-height: 40px;
	padding-left:0;
}
.webix_sidebar .webix_tree_branch_1{
	border-bottom:1px solid #e5e5e5;
}
.webix_sidebar .webix_tree_item.webix_selected span,
.webix_sidebar .webix_tree_item span{
	margin:0;
	padding:0px;
}
.webix_sidebar_icon{
	width: 40px;
	text-align: center;
}

.webix_sidebar_dir_icon{
	float: right;
	line-height: inherit;
}

/*SubMenu (Popup) */
.webix_sidebar_popup{
	border:none !important;
	box-shadow: 2px 3px 3px #ddd;
}
.webix_sidebar_popup, .webix_sidebar_popup .webix_list_item{
	border-radius:0;
}
.webix_sidebar_popup_right{
	box-shadow: -1px 3px 3px #ddd;
}
/*SubMenu: title*/
.webix_sidebar_popup_title{
	background: #ECEFF1;
}
.webix_sidebar_popup_title.webix_selected{
	border-left-color: #27ae60;
	background: #27ae60;
}
.webix_sidebar_popup_title .webix_template{
	line-height: 40px;
	padding: 0 10px;
	border: 1px solid #E5E5E5;
	border-left:none;
}
.webix_sidebar_selected.webix_sidebar_popup_title .webix_template{
	background: rgba(0,0,0,0.03);
	border-left: none;
}
.webix_sidebar_popup_list .webix_list_item{
	border-left: 1px solid #E5E5E5;
	border-right: 1px solid #E5E5E5;
}
/*SubMenu: list*/
.webix_sidebar_popup_list .webix_list_item:first-child{
	border-top: 1px solid #E5E5E5;
}
.webix_sidebar_popup_list .webix_list_item:hover{
	background: #f6f9fb;
}

.webix_sidebar_popup_list .webix_list_item.webix_selected:hover{
	background: #27ae60;
}